#include <iostream>
#include <Eigen/Dense>
#include <vector>
#include <string>

using Polylines = std::vector<std::vector<Eigen::Vector3d>>;

#include "features.inl"
#include "features_perturbed.inl"

using namespace std;

void reportStats(const string &name, const Polylines &curves) {
    cout << "Stats for " << name << endl;
    cout << curves.size() << " feature curves" << endl;

    for (size_t i = 0; i < curves.size(); ++i) {
        auto &c = curves[i];
        vector<double> lengths;
        for (size_t j = 0; j < c.size() - 1; ++j)
            lengths.push_back((c[j + 1] - c[j]).norm());
        
        cout << "curve " << i << " min/max feature segment length:\t"
             << *min_element(lengths.begin(), lengths.end()) << "\t"
             << *max_element(lengths.begin(), lengths.end())
             << endl;
    }
}

int main(int argc, const char *argv[]) {
    reportStats("original",  featureCurves);
    cout << endl;
    reportStats("perturbed", featureCurvesPerturbed);
    
    return 0;
}
